@@ -9,6 +9,21 @@ sites.put <- function(G, lname="", east, north, var,
 	if (class(G) != "grassmeta") stop("Data not a grass object")
 	if (length(lname) != 1)
 		stop("Single new GRASS data base file name required")
+	list.GRASS <- function(type = "rast") {
+	breakup <- function(chars) {
+	tmp <- unlist(strsplit(chars, split="\t"))
+	tmp1 <- character(0)
+	for (i in 1:length(tmp)) tmp1 <- c(tmp1,
+		 unlist(strsplit(tmp[i], split=" ")))
+	tmp1[nchar(tmp1) > 0]
+	}
+	res <- system(paste("g.list ", type, sep=""), intern=TRUE)
+	G.list <- character(0)
+	for(i in 3:(length(res)-1)) 
+	    if (nchar(res[i]) > 0) G.list <- c(G.list, breakup(res[i]))
+	invisible(G.list)
+	}
+
 	G.list <- list.GRASS(type="sites")
 	res <- lname %in% G.list
 	if (any(res))
